Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InitOTelGRF ¶
func InitOTelGRF() (*sdktrace.TracerProvider, error)
InitOTelGRF uses the Grafana recommended configuration including Baggage for propagation
Types ¶
type Artist ¶
type Artist struct {
ID string `json:"id"`
Name string `json:"name"`
Type string `json:"type"`
Country string `json:"country,omitempty"`
Disambiguation string `json:"disambiguation,omitempty"`
Score int `json:"score"`
}
Artist is a sub-target for unmarshalling the specific Artist keys we care about.
type MBAnswerArtist ¶
type MBAnswerArtist struct {
Count int `json:"count"`
Offset int `json:"offset"`
Artists []Artist `json:"artists"`
}
MBAnswerArtist is the primary target for unmarshalling the results JSON.
type MBQuestion ¶
type MBQuestion struct {
QString string
QType string
QFullURL string
RespBody string
// contains filtered or unexported fields
}
MBQuestion is the heart of operations, where data and client configs are kept
func NewMBQuestion ¶
func NewMBQuestion(qSearch, qType string) *MBQuestion
NewMBQuestion creates the object for asking and storing the answer.
func (*MBQuestion) ArtistSearch ¶
ArtistSearch uses context for the request and includes retry logic for backoff
Click to show internal directories.
Click to hide internal directories.